@@ -1,9 +1,33 @@
+import datetime
 import functools
+import io
 from importlib import import_module
-from typing import Any, Callable, List, Optional, TypeVar, Union
+from typing import (
+    Any,
+    BinaryIO,
+    Callable,
+    List,
+    Optional,
+    Tuple,
+    TypeVar,
+    Union,
+)
+
+import _io
 
 from neuroio.constants import sentinel
 
+ImageType = Union[BinaryIO, Tuple[str, io.BytesIO], bytes]
+
+
+def validate_month_str(month_str: str) -> None:
+    try:
+        datetime.datetime.strptime(month_str, "%Y-%m")
+    except ValueError:
+        raise ValueError(
+            f"Incorrect month format in {month_str}, should be YYYY-MM"
+        )
+
 
 def get_package_version() -> str:
     from neuroio import __version__
@@ -11,19 +35,6 @@ def get_package_version() -> str:
     return __version__
 
 
-def dynamic_import(abs_path: str, attribute: str) -> Any:
-    """
-    Imports any attribute from the module specified as string dotted path.
-    Takes into account current supplied version to the Client instance.
-
-    :param abs_path: dotted path of the module from which to import from
-    :param attribute: function, class or any other attr to be imported
-    :return: imported attribute
-    """
-    module_object = import_module(abs_path)
-    return getattr(module_object, attribute)
-
-
 F = TypeVar("F", bound=Callable[..., Any])
 
 
@@ -31,6 +42,22 @@ def cached_property(f: F) -> property:
     return property(functools.lru_cache()(f))
 
 
+def prepare_image_processing(
+    image: ImageType, filename: str = "image"
+) -> dict:
+    if isinstance(image, (bytes, bytearray)):
+        image_data = io.BytesIO(image)
+    elif isinstance(image, _io.BufferedReader):
+        image_data = image
+        filename = image.name
+    elif isinstance(image, tuple):
+        filename, image_data = image
+    else:
+        raise Exception("Wrong image datatype")
+
+    return {"image": (filename, image_data)}
+
+
 def process_query_params(params: dict) -> dict:
     for key, item in params.items():
         if isinstance(item, list):
